Documentation
¶
Overview ¶
Package win32ogl provides funtions for OpenGL applications for windows.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Context ¶
Context is the OpenGL context.
func (*Context) MakeCurrent ¶
MakeCurrent makes OpenGL context current.
func (*Context) Release ¶
Release makes OpenGL context no longer current. If any other context is current, it stays current.
func (*Context) SwapBuffers ¶
SwapBuffers swaps the front and back buffers.
type DummyWindow ¶
type DummyWindow struct {
Context Context
// contains filtered or unexported fields
}
DummyWindow is a window with OpenGL 1.1 context.
func (*DummyWindow) Destroy ¶
func (dummy *DummyWindow) Destroy() error
Destroy releases all resources associated with dummy window.
type MainLoop ¶
type MainLoop struct {
// contains filtered or unexported fields
}
MainLoop processes window events.
func (*MainLoop) AddUpdatable ¶
AddUpdatable adds an Updatable to main loop. Updatable is called, when event queue has no events.
func (*MainLoop) ProcessEvents ¶
func (loop *MainLoop) ProcessEvents()
ProcessEvents processes events and blocks until
func (*MainLoop) RemoveAllUpdatable ¶
func (loop *MainLoop) RemoveAllUpdatable()
RemoveAllUpdatable removes all Updatable.
func (*MainLoop) RemoveUpdatable ¶
RemoveUpdatable makes Updatable no more identified by id.
type OpenGL ¶
type OpenGL struct {
Funcs *C.win32ogl_opengl_t
// contains filtered or unexported fields
}
OpenGL holds OpenGL functions.
func (*OpenGL) LoadFunctions ¶
LoadFunctions loads OpenGL functions. An OpenGL context must have been set current before.